#!/bin/sh

#---------------------------------------------------------------------------
# Copyright (C) 2001  Marcin Krzyzanowski <krzak@linux.net.pl>
#---------------------------------------------------------------------------
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#---------------------------------------------------------------------------
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#---------------------------------------------------------------------------
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
#---------------------------------------------------------------------------

jikes=`find /usr/bin /bin /usr/local/bin -iname jikes`
javac=$JAVA_HOME/bin/javac
jar=$JAVA_HOME/bin/jar
javadoc=$JAVA_HOME/bin/javadoc
server_source=src/pl/net/linux/krzak/kchat/server
applet_source=src/pl/net/linux/krzak/kchat/applet
sac_source=src/pl/net/linux/krzak/kchat/sac
util_source=src/pl/net/linux/krzak/kchat/util
util_jar=jars/kChatutil.jar
target=""

export CLASSPATH=./classes:./src:$CLASSPATH

if [ -h $jikes ] || [ -r $jikes ]; then 
    echo "Jikes compiler detected";
    compiler=$jikes 
    target=" +P"
	else 
    echo "javac compiler detected";
    compiler=$javac
    target=' -target 1.1'
fi

rm -rf ./classes
rm -rf ./doc/javadoc

echo "Making directory structure"
mkdir -p classes/pl/net/linux/krzak/kchat/server
mkdir -p classes/pl/net/linux/krzak/kchat/applet
mkdir -p classes/pl/net/linux/krzak/kchat/sac
mkdir -p classes/pl/net/linux/krzak/kchat/util
mkdir -p doc/javadoc/applet
mkdir -p doc/javadoc/server
mkdir -p doc/javadoc/sac
mkdir -p doc/javadoc/util

echo "Compiling with kChatutil"
if [ -r $compiler ] && [ -r $server_source ] && [ -r $applet_source ]; then
    $compiler -d classes $util_source/*.java $target
    if [ -r $jar ]; then
	echo "Building kChatutil.jar" 
	cd classes
	$jar cf  ../$util_jar  pl/net/linux/krzak/kchat/util/
	$jar i ../$util_jar
	cd ..
    fi
fi

export CLASSPATH=./classes:./src:$CLASSPATH:$util_jar


echo "Compiling"
if [ -r $compiler ] && [ -r $server_source ] && [ -r $applet_source ]; then
    $compiler -d classes $server_source/kChatServer.java $target
    $compiler -d classes $sac_source/kChatSac.java $target
    $compiler -d classes $applet_source/kChatApplet.java $target
    if [ -r $jar ]; then
	echo "Building jars" 
	cd classes
	$jar cfm ../jars/kChatApplet.jar ../manifest/manifest-applet.mf pl/net/linux/krzak/kchat/applet
	$jar i ../jars/kChatApplet.jar
	$jar cfm ../jars/kChatServer.jar ../manifest/manifest-server.mf pl/net/linux/krzak/kchat/server
	$jar i ../jars/kChatServer.jar
	$jar cfm ../jars/kChatSac.jar    ../manifest/manifest-sac.mf pl/net/linux/krzak/kchat/sac
	$jar i ../jars/kChatSac.jar
	cd ..
    fi
fi

if [ -r $javadoc ]; then
    echo "Building javadoc"
    $javadoc -d doc/javadoc/applet $applet_source/*
    $javadoc -d doc/javadoc/server $server_source/*
    $javadoc -d doc/javadoc/sac $sac_source/*
    $javadoc -d doc/javadoc/util $util_source/*
fi

echo "Remove temporary files"
rm -rf ./classes

echo "Finish"