package pl.net.linux.krzak.kchat.sac;
/*****************************/
/* kChat v2.0pre2	     */
/* kChatSac v0.9	     */
/* krzak@linux.net.pl        */
/* Marcin Krzyzanowski       */
/* http://krzak.linux.net.pl */
/* License: GPL              */
/*****************************/
/* Copyright (C) 2001  Marcin Krzyzanowski <krzak@linux.net.pl>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
import java.awt.*;
import java.awt.event.*;
import java.util.Vector;
import java.io.*;

public class SacMainWindow implements ActionListener, ItemListener, WindowListener {
    public Frame    windowMain   = null;
    public SacList  nList        = null;
    public Button   bConnect     = new Button("CONNECT");
    public Button   bPrivate     = new Button("CHAT");
    public SacLabel status	 = new SacLabel("",Label.CENTER);
    public String   login	 = new String("nobody");
    public String   password	 = new String("password");
    public String   channel	 = new String("linux");
    public String   color	 = new String("black");
    public String   host	 = new String("localhost");
    public String   port	 = new String("1979");
    public String   selectedNick = new String();
    public Vector   windowsList  = new Vector();
    public SacNet   net		 = null;
    private TextField inputLogin    = null;
    private TextField inputPass     = null;
    private TextField inputChannel  = null;
    private TextField inputHost     = null;
    private TextField inputPort     = null;
    private Dialog    pdialog 	    = null;

    public SacMainWindow(String release) {
     if (release == null) release = "";
     
     MenuBar  menubar     = new MenuBar();
     Menu     configmenu  = new Menu("Preferences");
     Menu     aboutmenu   = new Menu("About");
     MenuItem mnParams    = new MenuItem("Config");
     MenuItem mnServer    = new MenuItem("Server");
     MenuItem mnAbout     = new MenuItem("About");

     mnParams.addActionListener(this);
     mnParams.setActionCommand("mnPARAMS_DIALOG");
     mnServer.addActionListener(this);
     mnServer.setActionCommand("mnSERVER_DIALOG");

     mnAbout.addActionListener(this);
     mnAbout.setActionCommand("mnABOUT_DIALOG");

     bConnect.setActionCommand("bCONNECT_CONNECT");
     bConnect.addActionListener(this);

     bPrivate.setActionCommand("bPRIVATE_CHAT");
     bPrivate.addActionListener(this);

     nList = new SacList();
     nList.addItemListener(this);
     nList.setBackground(Color.white);
     
     windowMain = new Frame(release);
     windowMain.addWindowListener(new SacMainWindowActions());
     windowMain.setSize(150,250);

     Panel panel = new Panel(new BorderLayout());
     Panel panelButtons = new Panel(new BorderLayout());
     
     panelButtons.add(bPrivate,BorderLayout.NORTH);
     panelButtons.add(bConnect,BorderLayout.CENTER);

     panel.add(nList,BorderLayout.CENTER);
     panel.add(panelButtons,BorderLayout.SOUTH);
     
     configmenu.add(mnParams);
     configmenu.add(mnServer);
     aboutmenu.add(mnAbout);
     menubar.add(configmenu);
     menubar.add(aboutmenu);
     windowMain.setMenuBar(menubar);

     windowMain.add(panel);
     windowMain.setVisible(true);
     readConfiguration();
    }
    
    
    public boolean alreadyExistNick(String nick) {
	WindowChat tmpW = new WindowChat();
	for (int i=0; i < windowsList.size(); i++){
	 tmpW = (WindowChat)windowsList.elementAt(i);
	 if (tmpW.nick.equals(nick)) return(true);
	 }
    return(false);
    }


    public MsgFloatingWindow getMsgWindowFromList(String nick) {
     WindowChat tmpW = new WindowChat();
     for (int i=0; i < windowsList.size(); i++){
         tmpW = (WindowChat)windowsList.elementAt(i);
         if (tmpW.nick.equals(nick)) return(tmpW.window);
         }
     return(null);
    }

    public void itemStateChanged(ItemEvent e) {
	if (e.getStateChange() == ItemEvent.SELECTED)
	    { selectedNick = nList.getSelectedItem(); }
    }

    public void actionPerformed(ActionEvent e) {
	if (e.getActionCommand().equals("bCONNECT_CONNECT")) {
	    net = new SacNet(host,port,this);
	    net.start();
	    net.send("*LOGIN|SYSTEM|"+login+"|"+password+"|"+channel+"|"+color+"|");
	    net.send("*CHECK|"+channel+"|");
	    bConnect.setActionCommand("bCONNECT_DISCONNECT");
	    if (net.connected)
		bConnect.setLabel("DISCONNECT");
	return;
	}
	
	if (e.getActionCommand().equals("bCONNECT_DISCONNECT")) {
	    bConnect.setActionCommand("bCONNECT_CONNECT");
	    net.disconnect();
	    nList.removeAll();
	    bConnect.setLabel("CONNECT");
	    net=null;
	return;
	}

	if (e.getActionCommand().equals("bPRIVATE_CHAT")) {
	 if ((!(login.equals(selectedNick))) &&
	    (!(selectedNick.equals(""))) &&
	    (alreadyExistNick(selectedNick) == false)) {
	    MsgFloatingWindow fw = new MsgFloatingWindow("Chat with "+selectedNick,selectedNick,this);
	    fw.setVisible(true);
	 }
	return;
	}

	if (e.getActionCommand().equals("mnABOUT_DIALOG")) {
	    pdialog = new Dialog(windowMain);
	    pdialog.addWindowListener(this);
	    pdialog.setSize(420,120);
	    Button bOK = new Button("OK");
	    bOK.setActionCommand("mnABOUT_bOK_OK");
	    bOK.addActionListener(this);
	    Panel panel = new Panel(new BorderLayout());
	    panel.add(new Label("author : Marcin Krzyzanowski",Label.CENTER),BorderLayout.NORTH);
	    panel.add(new Label("kChatSac is a part of kChat project, http://krzak.linux.net.pl",Label.CENTER),BorderLayout.CENTER);
	    panel.add(bOK,BorderLayout.SOUTH);
	    pdialog.add(panel);
	    pdialog.setVisible(true);
	return;
	}
	
	if (e.getActionCommand().equals("mnABOUT_bOK_OK")) {
	    pdialog.removeWindowListener(this);
	    pdialog.dispose();
	    pdialog=null;
	return;
	}

	if (e.getActionCommand().equals("mnPARAMS_DIALOG")) {
	    pdialog = new Dialog(windowMain);
	    pdialog.addWindowListener(this);
	    pdialog.setSize(100,120);
	    Button bOK = new Button("OK");
	    bOK.setActionCommand("mnPARAMS_bOK_OK");
	    bOK.addActionListener(this);
	    
	    inputLogin   = new TextField(login);
	    inputPass    = new TextField(password);
	    inputChannel = new TextField(channel);

	    Panel panelUser = new Panel(new BorderLayout());
	    panelUser.add(inputLogin,BorderLayout.NORTH);
	    panelUser.add(inputPass,BorderLayout.CENTER);
	    panelUser.add(inputChannel,BorderLayout.SOUTH);
	    
	    Panel panel = new Panel(new BorderLayout());
	    panel.add(panelUser,BorderLayout.CENTER);
	    panel.add(bOK,BorderLayout.SOUTH);
	    pdialog.add(panel);
	    pdialog.setVisible(true);
	return;
    	}
	
	if (e.getActionCommand().equals("mnPARAMS_bOK_OK")) {
	    login    = inputLogin.getText();
	    password = inputPass.getText();
	    channel  = inputChannel.getText();
	    pdialog.removeWindowListener(this);
	    pdialog.dispose();
	    pdialog=null;
	    inputLogin=null;
	    inputPass=null;
	    inputChannel=null;
	    writeConfiguration();
	return;
	}

	if (e.getActionCommand().equals("mnSERVER_DIALOG")) {
	    pdialog = new Dialog(windowMain);
	    pdialog.addWindowListener(this);
	    pdialog.setSize(100,95);
	    Button bOK = new Button("OK");
	    bOK.setActionCommand("mnSERVER_bOK_OK");
	    bOK.addActionListener(this);
	    
	    inputHost   = new TextField(host);
	    inputPort   = new TextField(port);

	    Panel panelHost = new Panel(new BorderLayout());
	    panelHost.add(inputHost,BorderLayout.NORTH);
	    panelHost.add(inputPort,BorderLayout.CENTER);
	
	    Panel panel = new Panel(new BorderLayout());
	    panel.add(panelHost,BorderLayout.CENTER);
	    panel.add(bOK,BorderLayout.SOUTH);
	    pdialog.add(panel);
	    pdialog.setVisible(true);
	return;
    	}

	if (e.getActionCommand().equals("mnSERVER_bOK_OK")) {
	    host    = inputHost.getText();
	    port    = inputPort.getText();
	    pdialog.removeWindowListener(this);
	    pdialog.dispose();
	    pdialog=null;
	    inputHost=null;
	    inputPort=null;
	    writeConfiguration();
	return;
	}


    }


    private void writeConfiguration() {
        try {
    	    FileWriter fw = new FileWriter("kChatSac.config",false);
	    BufferedWriter fwb = new BufferedWriter(fw);
	    fwb.write("login="+login);
 fwb.newLine();
	    fwb.write("password="+password);
 fwb.newLine();
	    fwb.write("channel="+channel);
 fwb.newLine();
	    fwb.write("host="+host);
 fwb.newLine();
	    fwb.write("port="+port);
	    fwb.flush();
	    fwb.close();
	    } catch (IOException e) { e.printStackTrace(); }
    }

    private void readConfiguration() {
        try {
    	    BufferedReader frb = new BufferedReader(new FileReader("kChatSac.config"));
	    String line= new String();
	    while ((line = frb.readLine()) !=null ) {
		String txttmp = line.substring(0,line.indexOf("=",0));
		String valtmp = line.substring(line.indexOf("=",0)+1);
		if (txttmp.equals("login")) 	login = valtmp;
		if (txttmp.equals("password")) 	password = valtmp;
		if (txttmp.equals("channel")) 	channel = valtmp;
		if (txttmp.equals("host")) 	host = valtmp;
		if (txttmp.equals("port")) 	port = valtmp;
		}
	    } catch (IOException e) { 
		System.out.println("No configuration file found !!!");
		configurationDialog();
		}
    }
    
    private void configurationDialog() {
	pdialog = new Dialog(windowMain);
	pdialog.addWindowListener(this);
	pdialog.setSize(100,120);
	Button bOK = new Button("OK");
	bOK.setActionCommand("mnPARAMS_bOK_OK");
	bOK.addActionListener(this);
	    
	inputLogin   = new TextField(login);
	inputPass    = new TextField(password);
	inputChannel = new TextField(channel);

	Panel panelUser = new Panel(new BorderLayout());
	panelUser.add(inputLogin,BorderLayout.NORTH);
	panelUser.add(inputPass,BorderLayout.CENTER);
	panelUser.add(inputChannel,BorderLayout.SOUTH);
	
	Panel panel = new Panel(new BorderLayout());
	panel.add(panelUser,BorderLayout.CENTER);
	panel.add(bOK,BorderLayout.SOUTH);
	pdialog.add(panel);
	pdialog.setVisible(true);
    }

    public void windowClosing(WindowEvent e) { e.getWindow().removeWindowListener(this); e.getWindow().dispose(); }
    public void windowClosed(WindowEvent e) {  }
    public void windowOpened(WindowEvent e) {  }
    public void windowIconified(WindowEvent e) { }
    public void windowDeiconified(WindowEvent e) { }
    public void windowActivated(WindowEvent e) { }
    public void windowDeactivated(WindowEvent e) { }
    
}